aboutsummaryrefslogtreecommitdiffstats
path: root/dumpcap.c
diff options
context:
space:
mode:
Diffstat (limited to 'dumpcap.c')
-rw-r--r--dumpcap.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/dumpcap.c b/dumpcap.c
index 7629d209dd..8849ac9b55 100644
--- a/dumpcap.c
+++ b/dumpcap.c
@@ -163,7 +163,7 @@ static void cap_pipe_close(int pipe_fd, gboolean from_socket);
* BSD), and we don't want to do it on Windows (because "select()" is
* something for sockets, not for arbitrary handles). (Note that "Windows"
* here includes Cygwin; even in its pretend-it's-UNIX environment, we're
- * using WinPcap, not a UNIX libpcap.)
+ * using Npcap, not a UNIX libpcap.)
*
* Fortunately, we don't need to do it on BSD, because the libpcap timeout
* on BSD times out even if no packets have arrived, so we'll eventually
@@ -610,16 +610,16 @@ get_pcap_failure_secondary_error_message(cap_device_open_err open_err,
{
#ifdef _WIN32
/*
* On Windows, first make sure they *have* WinPcap installed.
*/
if (!has_wpcap) {
return
- "In order to capture packets, WinPcap must be installed; see\n"
+ "In order to capture packets, Npcap or WinPcap must be installed. See\n"
"\n"
- " https://www.winpcap.org/\n"
+ " https://nmap.org/npcap/\n"
"\n"
- "for a downloadable version of WinPcap and for instructions on how to install\n"
- "WinPcap.";
+ "for a downloadable version of Npcap and for instructions on how to\n"
+ "install it.";
}
#endif
@@ -610,16 +610,16 @@ get_pcap_failure_secondary_error_message(cap_device_open_err open_err,
#ifdef _WIN32
/*
- * On Windows, first make sure they *have* WinPcap installed.
+ * On Windows, first make sure they *have* Npcap installed.
*/
if (!has_wpcap) {